@@ -166,13 +166,13 @@ static char * depflagsFormat(int_32 type, const void * data,
 		         char * formatPrefix, int padding, int element) {
     char * val;
     char buf[10];
-    int anint = *(((int_32 *) data) + element);
+    int anint = *((int_32 *) data);
 
     if (type != RPM_INT32_TYPE) {
 	val = malloc(20);
 	strcpy(val, _("(not a number)"));
     } else {
-	*buf = '\0';
+	buf[0] = '\0';
 
 	if (anint & RPMSENSE_LESS) 
 	    strcat(buf, "<");
@@ -233,18 +233,29 @@ static int fssizesTag(Header h, int_32 * type, void ** data, int_32 * count,
     uint_32 * usages;
     int numFiles;
 
-    headerGetEntry(h, RPMTAG_FILENAMES, NULL, (void **) &filenames, NULL);
-    headerGetEntry(h, RPMTAG_FILESIZES, NULL, (void **) &filesizes, &numFiles);
+    if (headerGetEntry(h, RPMTAG_FILENAMES, NULL, (void **) &filenames, NULL)) 
+	headerGetEntry(h, RPMTAG_FILESIZES, NULL, (void **) &filesizes, 
+		       &numFiles);
+    else
+	filenames = NULL;
 
     if (rpmGetFilesystemList(NULL, count)) {
 	return 1;
     }
 
+    *type = RPM_INT32_TYPE;
+    *freeData = 1;
+
+    if (!filenames) {
+	*data = usages = malloc(sizeof(usages) * (*count));
+	memset(usages, 0, sizeof(usages) * (*count));
+
+	return 0;
+    }
+
     if (rpmGetFilesystemUsage(filenames, filesizes, numFiles, &usages, 0))	
 	return 1;
 
-    *type = RPM_INT32_TYPE;
-    *freeData = 1;
     *data = usages;
 
     return 0;
