@@ -10,8 +10,6 @@
 #include "config.h"
 #include "miscfn.h"
 
-#include <zlib.h>
-
 #if HAVE_ALLOCA_H
 # include <alloca.h>
 #endif
@@ -26,6 +24,7 @@
 #include <netinet/in.h>
 
 #include "header.h"
+
 #include "intl.h"
 #include "tread.h"
 
@@ -142,6 +141,8 @@ static char * formatValue(struct sprintfTag * tag, Header h,
 			  struct extensionCache * extcache, int element);
 static char * octalFormat(int_32 type, const void * data, 
 		          char * formatPrefix, int padding, int element);
+static char * hexFormat(int_32 type, const void * data, char * formatPrefix, 
+			int padding, int element);
 static char * dateFormat(int_32 type, const void * data, 
 		          char * formatPrefix, int padding, int element);
 static char * dayFormat(int_32 type, const void * data, 
@@ -151,9 +152,11 @@ static char * shescapeFormat(int_32 type, const void * data,
 static int getExtension(Header h, headerTagTagFunction fn, int_32 * typeptr,
 			void ** data, int_32 * countptr, 
 			struct extensionCache * ext);
+char *headerFindI18NString(Header h, struct indexEntry *entry);
 
 const struct headerSprintfExtension headerDefaultFormats[] = {
     { HEADER_EXT_FORMAT, "octal", { octalFormat } },
+    { HEADER_EXT_FORMAT, "hex", { hexFormat } },
     { HEADER_EXT_FORMAT, "date", { dateFormat } },
     { HEADER_EXT_FORMAT, "day", { dayFormat } },
     { HEADER_EXT_FORMAT, "shescape", { shescapeFormat } },
@@ -443,6 +446,9 @@ Header headerLoad(void *pv)
 	entry->info.count = htonl(pe->count);
 	entry->info.offset = -1;
 
+        if (entry->info.type < RPM_MIN_TYPE ||
+            entry->info.type > RPM_MAX_TYPE) return NULL;
+
 	src = dataStart + htonl(pe->offset);
 	entry->length = dataLength(entry->info.type, src, 
 				   entry->info.count, 1);
@@ -669,7 +675,7 @@ void headerDump(Header h, FILE *f, int flags,
 		}
 		break;
 	    default:
-		fprintf(stderr, "Data type %d not supprted\n", 
+		fprintf(stderr, _("Data type %d not supprted\n"), 
 			(int) p->info.type);
 		exit(1);
 	    }
@@ -783,7 +789,6 @@ int headerGetEntry(Header h, int_32 tag, int_32 * type, void **p, int_32 * c)
 {
     struct indexEntry * entry;
     char * chptr;
-    int i;
 
     if (!p) return headerIsEntry(h, tag);
 
@@ -795,15 +800,11 @@ int headerGetEntry(Header h, int_32 tag, int_32 * type, void **p, int_32 * c)
     }
 
     if (entry->info.type == RPM_I18NSTRING_TYPE) {
-	if (h->langNum == -1) headerResetLang(h);
+	chptr = headerFindI18NString(h, entry);
 
 	if (type) *type = RPM_STRING_TYPE;
 	if (c) *c = 1;
 
-	chptr = entry->data;
-	for (i = 0; i < h->langNum; i++) 
-	    chptr += strlen(chptr) + 1;
-
 	*p = chptr;
     } else {
 	copyEntry(entry, type, p, c);
@@ -886,7 +887,7 @@ static int dataLength(int_32 type, void * p, int_32 count, int onDisk) {
 	    break;
 	}
         /* This should not be allowed */
-	fprintf(stderr, "grabData() RPM_STRING_TYPE count must be 1.\n");
+	fprintf(stderr, _("grabData() RPM_STRING_TYPE count must be 1.\n"));
 	exit(1);
 
       case RPM_STRING_ARRAY_TYPE:
@@ -916,7 +917,7 @@ static int dataLength(int_32 type, void * p, int_32 count, int onDisk) {
 	if (typeSizes[type] != -1)
 	    length = typeSizes[type] * count;
 	else {
-	    fprintf(stderr, "Data type %d not supported\n", (int) type);
+	    fprintf(stderr, _("Data type %d not supported\n"), (int) type);
 	    exit(1);
 	}
     }
@@ -975,7 +976,7 @@ int headerAddEntry(Header h, int_32 tag, int_32 type, void *p, int_32 c)
     h->sorted = 0;
 
     if (c <= 0) {
-	fprintf(stderr, "Bad count for headerAddEntry(): %d\n", (int) c);
+	fprintf(stderr, _("Bad count for headerAddEntry(): %d\n"), (int) c);
 	exit(1);
     }
 
@@ -1077,8 +1078,9 @@ int headerAddI18NString(Header h, int_32 tag, char * string, char * lang) {
 	memcpy(buf, entry->data, length);
 	strcpy(buf + length, string);
 	i = strlen(chptr + length) + 1;
-	memcpy(buf + strlen(string) + 1, ((char *) entry->data) + length + i, 
-		entry->length - length - i);
+	memcpy(buf + length + strlen(string) + 1,
+	       ((char *) entry->data) + length + i, 
+	       entry->length - length - i);
 
 	free(entry->data);
 	entry->data = buf;
@@ -1280,7 +1282,7 @@ static int parseExpression(struct sprintfToken * token, char * str,
     *chptr++ = '\0';;
 
     if (*chptr != '{') {
-	*error = _("{ exected after ? in expression");
+	*error = _("{ expected after ? in expression");
 	return 1;
     }
 
@@ -1310,7 +1312,7 @@ static int parseExpression(struct sprintfToken * token, char * str,
 	chptr++;
 
 	if (*chptr != '{') {
-	    *error = _("{ exected after : in expression");
+	    *error = _("{ expected after : in expression");
 	    freeFormat(token->u.cond.ifFormat, token->u.cond.numIfTokens);
 	    return 1;
 	}
@@ -1927,6 +1929,22 @@ static char * octalFormat(int_32 type, const void * data,
     return val;
 }
 
+static char * hexFormat(int_32 type, const void * data, 
+		          char * formatPrefix, int padding, int element) {
+    char * val;
+
+    if (type != RPM_INT32_TYPE) {
+	val = malloc(20);
+	strcpy(val, _("(not a number)"));
+    } else {
+	val = malloc(20 + padding);
+	strcat(formatPrefix, "x");
+	sprintf(val, formatPrefix, *((int_32 *) data));
+    }
+
+    return val;
+}
+
 static char * realDateFormat(int_32 type, const void * data, 
 			     char * formatPrefix, int padding, int element,
 			     char * strftimeFormat) {
@@ -2047,3 +2065,48 @@ void headerResetLang(Header h) {
    
     headerSetLangPath(h, getenv("LANG"));
 }
+
+char *headerFindI18NString(Header h, struct indexEntry *entry)
+{
+    char * lang, * buf, * chptr, * start, * next, * resptr;
+    struct indexEntry * table;
+    int langNum;
+
+    if (! (lang = getenv("LANGUAGE"))) {
+	lang = getenv("LANG");
+    }
+    
+    table = findEntry(h, HEADER_I18NTABLE, RPM_STRING_ARRAY_TYPE);
+
+    if (!lang || !table) {
+	return entry->data;
+    }
+
+    buf = alloca(strlen(lang) + 1);
+    strcpy(buf, lang);
+
+    start = buf;
+    while (start) {
+	chptr = strchr(start, ':');
+	if (chptr) *chptr = '\0';
+	
+	next = table->data;
+	resptr = entry->data;
+	for (langNum = 0; langNum < entry->info.count; langNum++) {
+	    if (!strcmp(next, start) && *resptr) break;
+	    next += strlen(next) + 1;
+	    resptr += strlen(resptr) + 1;
+	}
+	
+	if (langNum < entry->info.count) {
+	    return resptr;
+	}
+
+	if (chptr)
+	    start = chptr + 1;
+	else
+	    start = NULL;
+    }
+
+    return entry->data;
+}
