@@ -24,6 +24,7 @@
 #include "cpio.h"
 #include "header.h"
 #include "install.h"
+#include "intl.h"
 #include "md5.h"
 #include "messages.h"
 #include "misc.h"
@@ -112,7 +113,7 @@ int rpmInstallSourcePackage(char * rootdir, int fd, char ** specFile,
     if (rc) return rc;
 
     if (!isSource) {
-	rpmError(RPMERR_NOTSRPM, "source package expected, binary found");
+	rpmError(RPMERR_NOTSRPM, _("source package expected, binary found"));
 	return 2;
     }
 
@@ -184,11 +185,11 @@ static int assembleFileList(Header h, struct fileMemory * mem,
 	    if (!rawRelocations[i].oldPath) {
 		if (!numValid) {
 		    rpmError(RPMERR_NORELOCATE, 
-			     "package is not relocatable");
+			     _("package is not relocatable"));
 		    return 1;
 		} else if (numValid != 1){
 		    rpmError(RPMERR_NORELOCATE, 
-			     "package has multiple relocatable components");
+			     _("package has multiple relocatable components"));
 		    return 1;
 		}
 		relocations[i].oldPath = 
@@ -211,7 +212,7 @@ static int assembleFileList(Header h, struct fileMemory * mem,
 		    if (!strcmp(validRelocations[j],
 				relocations[i].oldPath)) break;
 		if (j == numValid) {
-		    rpmError(RPMERR_BADRELOCATE, "path %s is not relocatable",
+		    rpmError(RPMERR_BADRELOCATE, _("path %s is not relocatable"),
 			     relocations[i].oldPath);
 		    return 1;
 		}
@@ -293,7 +294,7 @@ static int assembleFileList(Header h, struct fileMemory * mem,
 		newName = alloca(newLen + strlen(mem->names[i]));
 		strcpy(newName, nextReloc->newPath);
 		strcat(newName, mem->names[i] + len);
-		rpmMessage(RPMMESS_DEBUG, "relocating %s to %s\n",
+		rpmMessage(RPMMESS_DEBUG, _("relocating %s to %s\n"),
 			   mem->names[i], newName);
 		mem->names[i] = newName;
 	    } 
@@ -341,7 +342,7 @@ static int assembleFileList(Header h, struct fileMemory * mem,
 		if (!strcmp(*lang, fileLangs[i])) break;
 	    if (!*lang) {
 		file->install = 0;
-		rpmMessage(RPMMESS_DEBUG, "not installing %s -- linguas\n",
+		rpmMessage(RPMMESS_DEBUG, _("not installing %s -- linguas\n"),
 			   file->relativePath);
 	    }
 	}
@@ -363,7 +364,7 @@ static void setFileOwners(Header h, struct fileInfo * files, int fileCount) {
 
     for (i = 0; i < fileCount; i++) {
 	if (unameToUid(fileOwners[i], &files[i].uid)) {
-	    rpmError(RPMERR_NOUSER, "user %s does not exist - using root", 
+	    rpmError(RPMERR_NOUSER, _("user %s does not exist - using root"), 
 			fileOwners[i]);
 	    files[i].uid = 0;
 	    /* turn off the suid bit */
@@ -371,7 +372,7 @@ static void setFileOwners(Header h, struct fileInfo * files, int fileCount) {
 	}
 
 	if (gnameToGid(fileGroups[i], &files[i].gid)) {
-	    rpmError(RPMERR_NOGROUP, "group %s does not exist - using root", 
+	    rpmError(RPMERR_NOGROUP, _("group %s does not exist - using root"), 
 			fileGroups[i]);
 	    files[i].gid = 0;
 	    /* turn off the sgid bit */
@@ -395,8 +396,8 @@ static void trimChangelog(Header h) {
 
     numToKeep = strtol(buf, &end, 10);
     if (*end) {
-	rpmError(RPMERR_RPMRC, "instchangelog value in rpmrc should be a "
-		    "number, but isn't");
+	rpmError(RPMERR_RPMRC, _("instchangelog value in rpmrc should be a "
+		    "number, but isn't"));
 	return;
     }
 
@@ -471,7 +472,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
     if (isSource) {
 	if (flags & RPMINSTALL_TEST) {
 	    rpmMessage(RPMMESS_DEBUG, 
-			"stopping install as we're running --test\n");
+			_("stopping install as we're running --test\n"));
 	    return 0;
 	}
 
@@ -502,15 +503,15 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	headerRemoveEntry(h, RPMTAG_FILEGIDS);
     
     if (!(flags & RPMINSTALL_NOARCH) && !archOkay(h)) {
-	rpmError(RPMERR_BADARCH, "package %s-%s-%s is for a different "
-	      "architecture", name, version, release);
+	rpmError(RPMERR_BADARCH, _("package %s-%s-%s is for a different "
+	      "architecture"), name, version, release);
 	headerFree(h);
 	return 2;
     }
 
     if (!(flags & RPMINSTALL_NOOS) && !osOkay(h)) {
-	rpmError(RPMERR_BADOS, "package %s-%s-%s is for a different "
-	      "operating system", name, version, release);
+	rpmError(RPMERR_BADOS, _("package %s-%s-%s is for a different "
+	      "operating system"), name, version, release);
 	headerFree(h);
 	return 2;
     }
@@ -521,7 +522,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	return 2;
     }
 
-    rpmMessage(RPMMESS_DEBUG, "package: %s-%s-%s files test = %d\n", 
+    rpmMessage(RPMMESS_DEBUG, _("package: %s-%s-%s files test = %d\n"), 
 		name, version, release, flags & RPMINSTALL_TEST);
 
     /* This canonicalizes the root */
@@ -585,8 +586,8 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 		if (rc == -1) return 2;
 		if (rc == 1) continue;		/* no matches */
 
-		rpmMessage(RPMMESS_DEBUG, "package %s is now obsolete and will"
-			   " be removed\n", obsoletes[i]);
+		rpmMessage(RPMMESS_DEBUG, _("package %s is now obsolete and will"
+			   " be removed\n"), obsoletes[i]);
 
 		toRemoveAlloced += matches.count;
 		j = toRemove ? intptr - toRemove : 0; 
@@ -618,7 +619,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
     if (rootdir) {
 	currDirLen = 50;
 	currDir = malloc(currDirLen);
-	while (!getcwd(currDir, currDirLen)) {
+	while (!getcwd(currDir, currDirLen) && errno == ERANGE) {
 	    currDirLen += 50;
 	    currDir = realloc(currDir, currDirLen);
 	}
@@ -696,7 +697,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	    }
 
 	    if (nsp && *nsp) {
-		rpmMessage(RPMMESS_DEBUG, "file %s in netshared path\n", 
+		rpmMessage(RPMMESS_DEBUG, _("file %s in netshared path\n"), 
 				files[i].relativePath);
 		files[i].action = SKIP;
 		files[i].state = RPMFILE_STATE_NETSHARED;
@@ -713,12 +714,12 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 		    if (exists(files[i].relativePath)) {
 			if (files[i].flags & RPMFILE_NOREPLACE) {
 			    rpmMessage(RPMMESS_DEBUG, 
-				"%s exists - creating with alternate name\n", 
+				_("%s exists - creating with alternate name\n"), 
 				files[i].relativePath);
 			    files[i].action = ALTNAME;
 			} else {
 			    rpmMessage(RPMMESS_DEBUG, 
-				"%s exists - backing up\n", 
+				_("%s exists - backing up\n"), 
 				files[i].relativePath);
 			    files[i].action = BACKUP;
 			}
@@ -751,13 +752,13 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	    chdir(currDir);
 	}
 
-	rpmMessage(RPMMESS_DEBUG, "stopping install as we're running --test\n");
+	rpmMessage(RPMMESS_DEBUG, _("stopping install as we're running --test\n"));
 	if (replacedList) free(replacedList);
 	if (freeFileMem) freeFileMemory(fileMem);
 	return 0;
     }
 
-    rpmMessage(RPMMESS_DEBUG, "running preinstall script (if any)\n");
+    rpmMessage(RPMMESS_DEBUG, _("running preinstall script (if any)\n"));
     if (runInstScript("/", h, RPMTAG_PREIN, RPMTAG_PREINPROG, scriptArg, 
 		      flags & RPMINSTALL_NOSCRIPTS, 0)) {
 	if (replacedList) free(replacedList);
@@ -788,7 +789,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 		newpath = alloca(strlen(files[i].relativePath) + 20);
 		strcpy(newpath, files[i].relativePath);
 		strcat(newpath, ".rpmnew");
-		rpmError(RPMMESS_ALTNAME, "warning: %s created as %s",
+		rpmError(RPMMESS_ALTNAME, _("warning: %s created as %s"),
 			files[i].relativePath, newpath);
 		files[i].relativePath = newpath;
 		
@@ -822,11 +823,11 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 		newpath = alloca(strlen(files[i].relativePath) + 20);
 		strcpy(newpath, files[i].relativePath);
 		strcat(newpath, ext);
-		rpmError(RPMMESS_BACKUP, "warning: %s saved as %s", 
+		rpmError(RPMMESS_BACKUP, _("warning: %s saved as %s"), 
 			files[i].relativePath, newpath);
 
 		if (rename(files[i].relativePath, newpath)) {
-		    rpmError(RPMERR_RENAME, "rename of %s to %s failed: %s",
+		    rpmError(RPMERR_RENAME, _("rename of %s to %s failed: %s"),
 			  files[i].relativePath, newpath, strerror(errno));
 		    if (replacedList) free(replacedList);
 		    if (freeFileMem) freeFileMemory(fileMem);
@@ -858,7 +859,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	    archiveSizePtr = NULL;
 
 	if (labelFormat) {
-	    printf(labelFormat, name, version, release);
+	    fprintf(stdout, labelFormat, name, version, release);
 	    fflush(stdout);
 	}
 
@@ -892,7 +893,7 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	if (headerGetEntry(h, RPMTAG_FILENAMES, NULL, (void **) &fileNames,
 		           &fileCount)) {
 	    fileStates = malloc(sizeof(*fileStates) * fileCount);
-	    memset(fileStates, RPMFILE_STATE_NOTINSTALLED, fileCount);
+	    memset(fileStates, RPMFILE_STATE_NORMAL, fileCount);
 	    headerAddEntry(h, RPMTAG_FILESTATES, RPM_CHAR_TYPE, fileStates, 
 			    fileCount);
 	    free(fileStates);
@@ -927,26 +928,28 @@ int rpmInstallPackage(char * rootdir, rpmdb db, int fd,
 	return 2;
     }
 
-    rpmMessage(RPMMESS_DEBUG, "running postinstall script (if any)\n");
+    rpmMessage(RPMMESS_DEBUG, _("running postinstall script (if any)\n"));
 
     if (runInstScript(rootdir, h, RPMTAG_POSTIN, RPMTAG_POSTINPROG, scriptArg,
 		      flags & RPMINSTALL_NOSCRIPTS, 0)) {
 	return 2;
     }
 
-    /* Run triggers this package sets off */
-    if (runTriggers(rootdir, db, RPMSENSE_TRIGGERIN, h, 0)) {
-	return 2;
-    }
+    if (!(flags & RPMINSTALL_NOTRIGGERS)) {
+	/* Run triggers this package sets off */
+	if (runTriggers(rootdir, db, RPMSENSE_TRIGGERIN, h, 0)) {
+	    return 2;
+	}
 
-    /* Run triggers in this package which are set off by other things in
-       the database. */
-    if (runImmedTriggers(rootdir, db, RPMSENSE_TRIGGERIN, h, 0)) {
-	return 2;
+	/* Run triggers in this package which are set off by other things in
+	   the database. */
+	if (runImmedTriggers(rootdir, db, RPMSENSE_TRIGGERIN, h, 0)) {
+	    return 2;
+	}
     }
 
     if (toRemove && flags & RPMINSTALL_UPGRADE) {
-	rpmMessage(RPMMESS_DEBUG, "removing old versions of package\n");
+	rpmMessage(RPMMESS_DEBUG, _("removing old versions of package\n"));
 	intptr = toRemove;
 
 	if (flags & RPMINSTALL_NOSCRIPTS)
@@ -1035,7 +1038,7 @@ static int installArchive(int fd, struct fileInfo * files,
     if (rc) {
 	/* this would probably be a good place to check if disk space
 	   was used up - if so, we should return a different error */
-	rpmError(RPMERR_CPIO, "unpacking of archive failed on file %s: %d: %s", 
+	rpmError(RPMERR_CPIO, _("unpacking of archive failed on file %s: %d: %s"), 
 		 failedFile, rc, strerror(errno));
 	return 1;
     }
@@ -1073,7 +1076,7 @@ static int packageAlreadyInstalled(rpmdb db, char * name, char * version,
 		*offset = matches.recs[i].recOffset;
 		if (!(flags & RPMINSTALL_REPLACEPKG)) {
 		    rpmError(RPMERR_PKGINSTALLED, 
-			  "package %s-%s-%s is already installed",
+			  _("package %s-%s-%s is already installed"),
 			  name, version, release);
 		    headerFree(sech);
 		    return 1;
@@ -1121,7 +1124,7 @@ static enum instActions decideFileFate(char * filespec, short dbMode,
 	   package has marked it as missingok */
 	if (!(instFlags & RPMINSTALL_ALLFILES) && 
 	      (newFlags & RPMFILE_MISSINGOK)) {
-	    rpmMessage(RPMMESS_DEBUG, "%s skipped due to missingok flag\n",
+	    rpmMessage(RPMMESS_DEBUG, _("%s skipped due to missingok flag\n"),
 			filespec);
 	    return SKIP;
 	} else
@@ -1139,18 +1142,18 @@ static enum instActions decideFileFate(char * filespec, short dbMode,
 
     if (diskWhat != newWhat) {
 	rpmMessage(RPMMESS_DEBUG, 
-	    "\tfile type on disk is different then package - saving\n");
+	    _("\tfile type on disk is different then package - saving\n"));
 	return SAVE;
     } else if (newWhat != dbWhat && diskWhat != dbWhat) {
-	rpmMessage(RPMMESS_DEBUG, "\tfile type in database is different then "
-		   "disk and package file - saving\n");
+	rpmMessage(RPMMESS_DEBUG, _("\tfile type in database is different then "
+		   "disk and package file - saving\n"));
 	return SAVE;
     } else if (dbWhat != newWhat) {
-	rpmMessage(RPMMESS_DEBUG, "\tfile type changed - replacing\n");
+	rpmMessage(RPMMESS_DEBUG, _("\tfile type changed - replacing\n"));
 	return CREATE;
     } else if (dbWhat != LINK && dbWhat != REG) {
 	rpmMessage(RPMMESS_DEBUG, 
-		"\tcan't check file for changes - replacing\n");
+		_("\tcan't check file for changes - replacing\n"));
 	return CREATE;
     }
 
@@ -1162,7 +1165,7 @@ static enum instActions decideFileFate(char * filespec, short dbMode,
 
 	if (rc) {
 	    /* assume the file has been removed, don't freak */
-	    rpmMessage(RPMMESS_DEBUG, "	file not present - creating");
+	    rpmMessage(RPMMESS_DEBUG, _("\tfile not present - creating"));
 	    return CREATE;
 	}
 	dbAttr = dbMd5;
@@ -1172,7 +1175,7 @@ static enum instActions decideFileFate(char * filespec, short dbMode,
 	i = readlink(filespec, buffer, sizeof(buffer) - 1);
 	if (i == -1) {
 	    /* assume the file has been removed, don't freak */
-	    rpmMessage(RPMMESS_DEBUG, "	file not present - creating");
+	    rpmMessage(RPMMESS_DEBUG, _("\tfile not present - creating"));
 	    return CREATE;
 	}
 	dbAttr = dbLink;
@@ -1185,14 +1188,14 @@ static enum instActions decideFileFate(char * filespec, short dbMode,
     if (!strcmp(dbAttr, buffer)) {
 	/* this config file has never been modified, so 
 	   just replace it */
-	rpmMessage(RPMMESS_DEBUG, "	old == current, replacing "
-		"with new version\n");
+	rpmMessage(RPMMESS_DEBUG, _("\told == current, replacing "
+		"with new version\n"));
 	return CREATE;
     }
 
     if (!strcmp(dbAttr, newAttr)) {
 	/* this file is the same in all versions of this package */
-	rpmMessage(RPMMESS_DEBUG, "	old == new, keeping\n");
+	rpmMessage(RPMMESS_DEBUG, _("\told == new, keeping\n"));
 	return KEEP;
     }
 
@@ -1200,7 +1203,7 @@ static enum instActions decideFileFate(char * filespec, short dbMode,
        the ones in the two packages are different. It would
        be nice if RPM was smart enough to at least try and
        merge the difference ala CVS, but... */
-    rpmMessage(RPMMESS_DEBUG, "	files changed too much - backing up\n");
+    rpmMessage(RPMMESS_DEBUG, _("\tfiles changed too much - backing up\n"));
 	    
     return SAVE;
 }
@@ -1262,8 +1265,8 @@ static int instHandleSharedFiles(rpmdb db, int ignoreOffset,
 	    secOffset = sharedList[i].secRecOffset;
 	    sech = rpmdbGetRecord(db, secOffset);
 	    if (!sech) {
-		rpmError(RPMERR_DBCORRUPT, "cannot read header at %d for "
-		      "uninstall", secOffset);
+		rpmError(RPMERR_DBCORRUPT, _("cannot read header at %d for "
+		      "uninstall"), secOffset);
 		rc = 1;
 		break;
 	    }
@@ -1275,12 +1278,12 @@ static int instHandleSharedFiles(rpmdb db, int ignoreOffset,
 	    headerGetEntry(sech, RPMTAG_RELEASE, &type, (void **) &release, 
 		     &secFileCount);
 
-	    rpmMessage(RPMMESS_DEBUG, "package %s-%s-%s contain shared files\n", 
+	    rpmMessage(RPMMESS_DEBUG, _("package %s-%s-%s contain shared files\n"), 
 		    name, version, release);
 
 	    if (!headerGetEntry(sech, RPMTAG_FILENAMES, &type, 
 			  (void **) &secFileList, &secFileCount)) {
-		rpmError(RPMERR_DBCORRUPT, "package %s contains no files",
+		rpmError(RPMERR_DBCORRUPT, _("package %s contains no files"),
 		      name);
 		headerFree(sech);
 		rc = 1;
@@ -1302,7 +1305,7 @@ static int instHandleSharedFiles(rpmdb db, int ignoreOffset,
  	secNum = sharedList[i].secFileNumber;
 	mainNum = sharedList[i].mainFileNumber;
 
-	rpmMessage(RPMMESS_DEBUG, "file %s is shared\n", secFileList[secNum]);
+	rpmMessage(RPMMESS_DEBUG, _("file %s is shared\n"), secFileList[secNum]);
 
 	if (notErrors) {
 	    intptr = notErrors;
@@ -1318,10 +1321,10 @@ static int instHandleSharedFiles(rpmdb db, int ignoreOffset,
 	   replaced, just forget about it */
 	state = secFileStatesList[sharedList[i].secFileNumber];
 	if (state == RPMFILE_STATE_REPLACED) {
-	    rpmMessage(RPMMESS_DEBUG, "	old version already replaced\n");
+	    rpmMessage(RPMMESS_DEBUG, _("\told version already replaced\n"));
 	    continue;
 	} else if (state == RPMFILE_STATE_NOTINSTALLED) {
-	    rpmMessage(RPMMESS_DEBUG, "	other version never installed\n");
+	    rpmMessage(RPMMESS_DEBUG, _("\tother version never installed\n"));
 	    continue;
 	}
 
@@ -1329,8 +1332,8 @@ static int instHandleSharedFiles(rpmdb db, int ignoreOffset,
 		    files[mainNum].link, secFileModesList[secNum],
 		    secFileMd5List[secNum], secFileLinksList[secNum])) {
 	    if (!(flags & RPMINSTALL_REPLACEFILES) && !intptr) {
-		rpmError(RPMERR_PKGINSTALLED, "%s conflicts with file from "
-		         "%s-%s-%s", 
+		rpmError(RPMERR_PKGINSTALLED, _("%s conflicts with file from "
+		         "%s-%s-%s"), 
 			 files[sharedList[i].mainFileNumber].relativePath,
 		         name, version, release);
 		rc = 1;
@@ -1348,7 +1351,7 @@ static int instHandleSharedFiles(rpmdb db, int ignoreOffset,
 		    sharedList[i].secFileNumber;
 		numReplacedFiles++;
 
-		rpmMessage(RPMMESS_DEBUG, "%s from %s-%s-%s will be replaced\n", 
+		rpmMessage(RPMMESS_DEBUG, _("%s from %s-%s-%s will be replaced\n"), 
 			files[sharedList[i].mainFileNumber].relativePath,
 			name, version, release);
 	    }
@@ -1412,7 +1415,7 @@ static int installSources(Header h, char * rootdir, int fd,
     uid_t currUid = getuid();
     gid_t currGid = getgid();
 
-    rpmMessage(RPMMESS_DEBUG, "installing a source package\n");
+    rpmMessage(RPMMESS_DEBUG, _("installing a source package\n"));
 
     sourceDir = rpmGetVar(RPMVAR_SOURCEDIR);
     specDir = rpmGetVar(RPMVAR_SPECDIR);
@@ -1428,17 +1431,17 @@ static int installSources(Header h, char * rootdir, int fd,
     strcat(realSpecDir, specDir);
 
     if (access(realSourceDir, W_OK)) {
-	rpmError(RPMERR_CREATE, "cannot write to %s", realSourceDir);
+	rpmError(RPMERR_CREATE, _("cannot write to %s"), realSourceDir);
 	return 2;
     }
 
     if (access(realSpecDir, W_OK)) {
-	rpmError(RPMERR_CREATE, "cannot write to %s", realSpecDir);
+	rpmError(RPMERR_CREATE, _("cannot write to %s"), realSpecDir);
 	return 2;
     }
 
-    rpmMessage(RPMMESS_DEBUG, "sources in: %s\n", realSourceDir);
-    rpmMessage(RPMMESS_DEBUG, "spec file in: %s\n", realSpecDir);
+    rpmMessage(RPMMESS_DEBUG, _("sources in: %s\n"), realSourceDir);
+    rpmMessage(RPMMESS_DEBUG, _("spec file in: %s\n"), realSpecDir);
 
     if (h && headerIsEntry(h, RPMTAG_FILENAMES)) {
 	/* we can't remap v1 packages */
@@ -1471,7 +1474,7 @@ static int installSources(Header h, char * rootdir, int fd,
 	    strcat(files[i].relativePath, "/");
 	    strcat(files[i].relativePath, files[i].cpioPath);
 	} else {
-	    rpmError(RPMERR_NOSPEC, "source package contains no .spec file");
+	    rpmError(RPMERR_NOSPEC, _("source package contains no .spec file"));
 	    if (fileCount > 0) freeFileMemory(fileMem);
 	    return 2;
 	}
@@ -1484,7 +1487,7 @@ static int installSources(Header h, char * rootdir, int fd,
 	if (!headerGetEntry(h, RPMTAG_ARCHIVESIZE, &type, 
 				(void *) &archiveSizePtr, &count))
 	    archiveSizePtr = NULL;
-	printf(labelFormat, name, version, release);
+	fprintf(stdout, labelFormat, name, version, release);
 	fflush(stdout);
     }
 
@@ -1510,7 +1513,7 @@ static int installSources(Header h, char * rootdir, int fd,
 
     if (specFileIndex == -1) {
 	if (!specFile) {
-	    rpmError(RPMERR_NOSPEC, "source package contains no .spec file");
+	    rpmError(RPMERR_NOSPEC, _("source package contains no .spec file"));
 	    return 1;
 	}
 
@@ -1530,9 +1533,9 @@ static int installSources(Header h, char * rootdir, int fd,
 	free(specFile);
 
 	rpmMessage(RPMMESS_DEBUG, 
-		    "renaming %s to %s\n", instSpecFile, correctSpecFile);
+		    _("renaming %s to %s\n"), instSpecFile, correctSpecFile);
 	if (rename(instSpecFile, correctSpecFile)) {
-	    rpmError(RPMERR_RENAME, "rename of %s to %s failed: %s",
+	    rpmError(RPMERR_RENAME, _("rename of %s to %s failed: %s"),
 		     instSpecFile, correctSpecFile, strerror(errno));
 	    return 2;
 	}
@@ -1597,25 +1600,24 @@ static int markReplacedFiles(rpmdb db, struct replacedFile * replList) {
 
 int rpmVersionCompare(Header first, Header second) {
     char * one, * two;
-    int_32 * serialOne, * serialTwo;
+    int_32 * epochOne, * epochTwo;
     int rc;
 
-    if (!headerGetEntry(first, RPMTAG_SERIAL, NULL, (void **) &serialOne, NULL))
-	serialOne = NULL;
-    if (!headerGetEntry(second, RPMTAG_SERIAL, NULL, (void **) &serialTwo, 
+    if (!headerGetEntry(first, RPMTAG_EPOCH, NULL, (void **) &epochOne, NULL))
+	epochOne = NULL;
+    if (!headerGetEntry(second, RPMTAG_EPOCH, NULL, (void **) &epochTwo, 
 			NULL))
-	serialTwo = NULL;
+	epochTwo = NULL;
 
-    if (serialOne && !serialTwo) 
+    if (epochOne && !epochTwo) 
 	return 1;
-    else if (!serialOne && serialTwo) 
+    else if (!epochOne && epochTwo) 
 	return -1;
-    else if (serialOne && serialTwo) {
-	if (*serialOne < *serialTwo)
+    else if (epochOne && epochTwo) {
+	if (*epochOne < *epochTwo)
 	    return -1;
-	else if (*serialOne > *serialTwo)
+	else if (*epochOne > *epochTwo)
 	    return 1;
-	return 0;
     }
 	
     headerGetEntry(first, RPMTAG_VERSION, NULL, (void **) &one, NULL);
@@ -1647,8 +1649,8 @@ static int ensureOlder(rpmdb db, Header new, int dbOffset) {
 	headerGetEntry(old, RPMTAG_NAME, NULL, (void **) &name, NULL);
 	headerGetEntry(old, RPMTAG_VERSION, NULL, (void **) &version, NULL);
 	headerGetEntry(old, RPMTAG_RELEASE, NULL, (void **) &release, NULL);
-	rpmError(RPMERR_OLDPACKAGE, "package %s-%s-%s (which is newer) is "
-		"already installed", name, version, release);
+	rpmError(RPMERR_OLDPACKAGE, _("package %s-%s-%s (which is newer) is "
+		"already installed"), name, version, release);
     }
 
     headerFree(old);
