@@ -723,6 +723,10 @@ static void defaultMachine(char ** arch, char ** os) {
 #	    if defined(CPU_PA_RISC1_2)
 		if (cpu_version == CPU_PA_RISC1_2)
 		    strcpy(un.machine, "parisc");
+#	    endif
+#	    if defined(CPU_PA_RISC2_0)
+		if (cpu_version == CPU_PA_RISC2_0)
+		    strcpy(un.machine, "parisc");
 #	    endif
 	}
 #	endif
@@ -942,8 +946,8 @@ static void getMachineInfo(int type, char ** name, int * num) {
 	if (name) *name = current[type];
 
 	if (tables[currTables[type]].hasCanon) {
-	    rpmMessage(RPMMESS_WARNING, "Unknown system: %s\n", current[type]);
-	    rpmMessage(RPMMESS_WARNING, "Please contact rpm-list@redhat.com\n");
+	    rpmMessage(RPMMESS_WARNING, _("Unknown system: %s\n"), current[type]);
+	    rpmMessage(RPMMESS_WARNING, _("Please contact rpm-list@redhat.com\n"));
 	}
     }
 }
