@@ -150,7 +150,7 @@ static int handleSharedFiles(rpmdb db, int offset, char ** fileList,
 
 	    if (!headerGetEntry(sech, RPMTAG_FILENAMES, &type, 
 			  (void **) &secFileList, &secFileCount)) {
-		rpmError(RPMERR_DBCORRUPT, "package %s contains no files",
+		rpmError(RPMERR_DBCORRUPT, _("package %s contains no files"),
 		      name);
 		headerFree(sech);
 		rc = 1;
@@ -163,7 +163,7 @@ static int handleSharedFiles(rpmdb db, int offset, char ** fileList,
 		   implement --justdb properly, and chose to leave this stuff
 		   out. */
 		rpmMessage(RPMMESS_DEBUG, 
-			    "package is missing FILESTATES\n");
+			    _("package is missing FILESTATES\n"));
 		secFileStatesList = alloca(secFileCount);
 		memset(secFileStatesList, RPMFILE_STATE_NOTINSTALLED,
 			secFileCount);
@@ -173,27 +173,27 @@ static int handleSharedFiles(rpmdb db, int offset, char ** fileList,
 		     (void **) &secFileMd5List, &secFileCount);
 	}
 
-	rpmMessage(RPMMESS_DEBUG, "file %s is shared\n",
+	rpmMessage(RPMMESS_DEBUG, _("file %s is shared\n"),
 		fileList[sharedList[i].mainFileNumber]);
 	
 	switch (secFileStatesList[sharedList[i].secFileNumber]) {
 	  case RPMFILE_STATE_REPLACED:
-	    rpmMessage(RPMMESS_DEBUG, "     file has already been replaced\n");
+	    rpmMessage(RPMMESS_DEBUG, _("     file has already been replaced\n"));
 	    break;
 
 	  case RPMFILE_STATE_NOTINSTALLED:
-	    rpmMessage(RPMMESS_DEBUG, "     file was never installed\n");
+	    rpmMessage(RPMMESS_DEBUG, _("     file was never installed\n"));
 	    break;
     
 	  case RPMFILE_STATE_NETSHARED:
-	    rpmMessage(RPMMESS_DEBUG, "     file is netshared (so don't touch it)\n");
+	    rpmMessage(RPMMESS_DEBUG, _("     file is netshared (so don't touch it)\n"));
 	    fileActions[sharedList[i].mainFileNumber] = KEEP;
 	    break;
     
 	  case RPMFILE_STATE_NORMAL:
 	    if (!strcmp(fileMd5List[sharedList[i].mainFileNumber],
 			secFileMd5List[sharedList[i].secFileNumber])) {
-		rpmMessage(RPMMESS_DEBUG, "    file is truely shared - saving\n");
+		rpmMessage(RPMMESS_DEBUG, _("    file is truely shared - saving\n"));
 	    }
 	    fileActions[sharedList[i].mainFileNumber] = KEEP;
 	    break;
@@ -232,7 +232,7 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
 
     h = rpmdbGetRecord(db, offset);
     if (!h) {
-	rpmError(RPMERR_DBCORRUPT, "cannot read header at %d for uninstall",
+	rpmError(RPMERR_DBCORRUPT, _("cannot read header at %d for uninstall"),
 	      offset);
 	return 1;
     }
@@ -243,7 +243,7 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
     /* when we run scripts, we pass an argument which is the number of 
        versions of this package that will be installed when we are finished */
     if (rpmdbFindPackage(db, name, &matches)) {
-	rpmError(RPMERR_DBCORRUPT, "cannot read packages named %s for uninstall",
+	rpmError(RPMERR_DBCORRUPT, _("cannot read packages named %s for uninstall"),
 	      name);
 	return 1;
     }
@@ -251,14 +251,17 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
     scriptArg = matches.count - 1;
     dbiFreeIndexRecord(matches);
 
-    /* run triggers from this package which are keyed on installed packages */
-    if (runImmedTriggers(prefix, db, RPMSENSE_TRIGGERUN, h, -1)) {
-	return 2;
-    }
+    if (!(flags & RPMUNINSTALL_NOTRIGGERS)) {
+	/* run triggers from this package which are keyed on installed 
+	   packages */
+	if (runImmedTriggers(prefix, db, RPMSENSE_TRIGGERUN, h, -1)) {
+	    return 2;
+	}
 
-    /* run triggers which are set off by the removal of this package */
-    if (runTriggers(prefix, db, RPMSENSE_TRIGGERUN, h, -1))
-	return 1;
+	/* run triggers which are set off by the removal of this package */
+	if (runTriggers(prefix, db, RPMSENSE_TRIGGERUN, h, -1))
+	    return 1;
+    }
 
     if (!(flags & RPMUNINSTALL_TEST)) {
 	if (runInstScript(prefix, h, RPMTAG_PREUN, RPMTAG_PREUNPROG, scriptArg, 
@@ -268,7 +271,7 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
 	}
     }
     
-    rpmMessage(RPMMESS_DEBUG, "will remove files test = %d\n", 
+    rpmMessage(RPMMESS_DEBUG, _("will remove files test = %d\n"), 
 		flags & RPMUNINSTALL_TEST);
     if (!(flags & RPMUNINSTALL_JUSTDB) &&
 	headerGetEntry(h, RPMTAG_FILENAMES, &type, (void **) &fileList, 
@@ -290,7 +293,7 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
 	    /* This shouldn't happen, but some versions of RPM didn't
 	       implement --justdb properly, and chose to leave this stuff
 	       out. */
-	    rpmMessage(RPMMESS_DEBUG, "package is missing FILESTATES\n");
+	    rpmMessage(RPMMESS_DEBUG, _("package is missing FILESTATES\n"));
 	    fileStatesList = alloca(fileCount);
 	    memset(fileStatesList, RPMFILE_STATE_NOTINSTALLED,
 		    fileCount);
@@ -316,7 +319,7 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
 		for (i = 0; i < fileCount; i++) 
 		if (!strncmp(fileList[i], *nsp, j) &&
 		    (fileList[i][j] == '\0' || fileList[i][j] == '/')) {
-		    rpmMessage(RPMMESS_DEBUG, "%s has a netshared override\n",
+		    rpmMessage(RPMMESS_DEBUG, _("%s has a netshared override\n"),
 				fileList[i]);
 		    fileActions[i] = KEEP;
 		}
@@ -354,19 +357,21 @@ int rpmRemovePackage(char * prefix, rpmdb db, unsigned int offset, int flags) {
     }
 
     if (!(flags & RPMUNINSTALL_TEST)) {
-	rpmMessage(RPMMESS_DEBUG, "running postuninstall script (if any)\n");
+	rpmMessage(RPMMESS_DEBUG, _("running postuninstall script (if any)\n"));
 	runInstScript(prefix, h, RPMTAG_POSTUN, RPMTAG_POSTUNPROG, scriptArg, 
 		      flags & RPMUNINSTALL_NOSCRIPTS, 0);
     }
 
-    /* Run postun triggers which are set off by this package's removal */
-    if (runTriggers(prefix, db, RPMSENSE_TRIGGERPOSTUN, h, 0)) {
-	return 2;
+    if (!(flags & RPMUNINSTALL_NOTRIGGERS)) {
+	/* Run postun triggers which are set off by this package's removal */
+	if (runTriggers(prefix, db, RPMSENSE_TRIGGERPOSTUN, h, 0)) {
+	    return 2;
+	}
     }
 
     headerFree(h);
 
-    rpmMessage(RPMMESS_DEBUG, "removing database entry\n");
+    rpmMessage(RPMMESS_DEBUG, _("removing database entry\n"));
     if (!(flags & RPMUNINSTALL_TEST))
 	rpmdbRemove(db, offset, 0);
 
@@ -560,13 +565,13 @@ static int removeFile(char * file, char state, unsigned int flags, char * md5,
 	
     switch (state) {
       case RPMFILE_STATE_REPLACED:
-	rpmMessage(RPMMESS_DEBUG, "%s has already been replaced\n", file);
+	rpmMessage(RPMMESS_DEBUG, _("%s has already been replaced\n"), file);
 	break;
 
       case RPMFILE_STATE_NORMAL:
 	if ((action == REMOVE) && (flags & RPMFILE_CONFIG)) {
 	    /* if it's a config file, we may not want to remove it */
-	    rpmMessage(RPMMESS_DEBUG, "finding md5sum of %s\n", file);
+	    rpmMessage(RPMMESS_DEBUG, _("finding md5sum of %s\n"), file);
 	    if (brokenMd5)
 		rc = mdfileBroken(file, currentMd5);
 	    else
@@ -574,14 +579,14 @@ static int removeFile(char * file, char state, unsigned int flags, char * md5,
 
 	    if (mdfile(file, currentMd5)) 
 		rpmMessage(RPMMESS_DEBUG, 
-				"    failed - assuming file removed\n");
+				_("    failed - assuming file removed\n"));
 	    else {
 		if (strcmp(currentMd5, md5)) {
-		    rpmMessage(RPMMESS_DEBUG, "    file changed - will save\n");
+		    rpmMessage(RPMMESS_DEBUG, _("    file changed - will save\n"));
 		    action = BACKUP;
 		} else {
 		    rpmMessage(RPMMESS_DEBUG, 
-				"    file unchanged - will remove\n");
+				_("    file unchanged - will remove\n"));
 		}
 	    }
 	}
@@ -589,11 +594,11 @@ static int removeFile(char * file, char state, unsigned int flags, char * md5,
 	switch (action) {
 
 	  case KEEP:
-	    rpmMessage(RPMMESS_DEBUG, "keeping %s\n", file);
+	    rpmMessage(RPMMESS_DEBUG, _("keeping %s\n"), file);
 	    break;
 
 	  case BACKUP:
-	    rpmMessage(RPMMESS_DEBUG, "saving %s as %s.rpmsave\n", file, file);
+	    rpmMessage(RPMMESS_DEBUG, _("saving %s as %s.rpmsave\n"), file, file);
 	    if (!test) {
 		newfile = alloca(strlen(file) + 20);
 		strcpy(newfile, file);
@@ -607,7 +612,7 @@ static int removeFile(char * file, char state, unsigned int flags, char * md5,
 	    break;
 
 	  case REMOVE:
-	    rpmMessage(RPMMESS_DEBUG, "%s - removing\n", file);
+	    rpmMessage(RPMMESS_DEBUG, _("%s - removing\n"), file);
 	    if (S_ISDIR(mode)) {
 		if (!test) {
 		    if (rmdir(file)) {
@@ -652,6 +657,7 @@ static int handleOneTrigger(char * root, rpmdb db, int sense, Header sourceH,
     int i;
     int index;
     dbiIndexSet matches;
+    int skip;
 
     if (!headerGetEntry(triggeredH, RPMTAG_TRIGGERNAME, NULL, 
 			(void **) &triggerNames, &numTriggers)) {
@@ -669,7 +675,19 @@ static int handleOneTrigger(char * root, rpmdb db, int sense, Header sourceH,
     for (i = 0; i < numTriggers; i++) {
 	if (!(triggerFlags[i] & sense)) continue;
 	if (strcmp(triggerNames[i], sourceName)) continue;
-	if (!headerMatchesDepFlags(sourceH, triggerVersions[i], 
+
+	/* For some reason, the TRIGGERVERSION stuff includes the name
+	   of the package which the trigger is based on. We need to skip
+	   over that here. I suspect that we'll change our minds on this
+	   and remove that, so I'm going to just 'do the right thing'. */
+	skip = strlen(triggerNames[i]);
+	if (!strncmp(triggerVersions[i], triggerNames[i], skip) &&
+	    (triggerVersions[i][skip] == '-'))
+	    skip++;
+	else
+	    skip = 0;
+
+	if (!headerMatchesDepFlags(sourceH, triggerVersions[i] + skip, 
 				   triggerFlags[i])) continue;
 
 	headerGetEntry(triggeredH, RPMTAG_TRIGGERINDEX, NULL,
