@@ -15,6 +15,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#include "intl.h"
 #include "md5.h"
 #include "misc.h"
 #include "messages.h"
@@ -182,8 +183,8 @@ int rpmVerifyFile(char * prefix, Header h, int filenum, int * result,
 	    if (uidList[filenum] != sb.st_uid)
 		*result |= RPMVERIFY_GROUP;
 	} else {
-	    rpmError(RPMERR_INTERNAL, "package lacks both user name and id "
-		  "lists (this should never happen)");
+	    rpmError(RPMERR_INTERNAL, _("package lacks both user name and id "
+		  "lists (this should never happen)"));
 	    *result |= RPMVERIFY_GROUP;
 	}
     }
@@ -200,8 +201,8 @@ int rpmVerifyFile(char * prefix, Header h, int filenum, int * result,
 	    if (gidList[filenum] != sb.st_gid)
 		*result |= RPMVERIFY_GROUP;
 	} else {
-	    rpmError(RPMERR_INTERNAL, "package lacks both group name and id "
-		     "lists (this should never happen)");
+	    rpmError(RPMERR_INTERNAL, _("package lacks both group name and id "
+		     "lists (this should never happen)"));
 	    *result |= RPMVERIFY_GROUP;
 	}
     }
