@@ -15,6 +15,14 @@
 # include <alloca.h>
 #endif
 
+#if HAVE_LIMITS_H
+# include <limits.h>
+#endif
+
+#ifndef PATH_MAX
+# define PATH_MAX 255
+#endif
+
 #include "intl.h"
 #include "lib/messages.h"
 #include "miscfn.h"
@@ -66,7 +74,7 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
     headerGetEntry(h, RPMTAG_RELEASE, &type, (void **) &release, &count);
 
     if (!queryFormat && !queryFlags) {
-	printf("%s-%s-%s\n", name, version, release);
+	fprintf(stdout, "%s-%s-%s\n", name, version, release);
     } else {
 	if (queryFormat)
 	    queryHeader(h, queryFormat);
@@ -74,7 +82,8 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 	if (queryFlags & QUERY_FOR_LIST) {
 	    if (!headerGetEntry(h, RPMTAG_FILENAMES, &type, (void **) &fileList, 
 		 &count)) {
-		puts(_("(contains no files)"));
+		fputs(_("(contains no files)"), stdout);
+		fputs("\n", stdout);
 	    } else {
 		if (!headerGetEntry(h, RPMTAG_FILESTATES, &type, 
 			 (void **) &fileStatesList, &count)) {
@@ -126,50 +135,51 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 			    if (fileStatesList) {
 				switch (fileStatesList[i]) {
 				  case RPMFILE_STATE_NORMAL:
-				    fputs("normal        ", stdout); break;
+				    fputs(_("normal        "), stdout); break;
 				  case RPMFILE_STATE_REPLACED:
-				    fputs("replaced      ", stdout); break;
+				    fputs(_("replaced      "), stdout); break;
 				  case RPMFILE_STATE_NETSHARED:
-				    fputs("net shared    ", stdout); break;
+				    fputs(_("net shared    "), stdout); break;
 				  case RPMFILE_STATE_NOTINSTALLED:
-				    fputs("not installed ", stdout); break;
+				    fputs(_("not installed "), stdout); break;
 				  default:
-				    printf("(unknown %3d) ", 
+				    fprintf(stdout, _("(unknown %3d) "), 
 					  fileStatesList[i]);
 				}
 			    } else {
-				fputs(    "(no state)    ", stdout);
+				fputs(    _("(no state)    "), stdout);
 			    }
 			}
 			    
 			if (queryFlags & QUERY_FOR_DUMPFILES) {
-			    printf("%s %d %d %s 0%o ", fileList[i],
+			    fprintf(stdout, "%s %d %d %s 0%o ", fileList[i],
 				   fileSizeList[i], fileMTimeList[i],
 				   fileMD5List[i], fileModeList[i]);
 
 			    if (fileOwnerList)
-				printf("%s %s", fileOwnerList[i], 
+				fprintf(stdout, "%s %s", fileOwnerList[i], 
 						fileGroupList[i]);
 			    else if (fileUIDList)
-				printf("%d %d", fileUIDList[i], 
+				fprintf(stdout, "%d %d", fileUIDList[i], 
 						fileGIDList[i]);
 			    else {
-				rpmError(RPMERR_INTERNAL, "package has "
-					"neither file owner or id lists");
+				rpmError(RPMERR_INTERNAL, _("package has "
+					"neither file owner or id lists"));
 			    }
 
-			    printf(" %s %s %d ", 
+			    fprintf(stdout, " %s %s %d ", 
 				 fileFlagsList[i] & RPMFILE_CONFIG ? "1" : "0",
 				 fileFlagsList[i] & RPMFILE_DOC ? "1" : "0",
 				 fileRdevList[i]);
 
 			    if (strlen(fileLinktoList[i]))
-				printf("%s\n", fileLinktoList[i]);
+				fprintf(stdout, "%s\n", fileLinktoList[i]);
 			    else
-				printf("X\n");
+				fprintf(stdout, "X\n");
 
 			} else if (!rpmIsVerbose()) {
-			    puts(fileList[i]);
+			    fputs(fileList[i], stdout);
+			    fputs("\n", stdout);
 			} else if (fileOwnerList) 
 			    printFileInfo(fileList[i], fileSizeList[i],
 					  fileModeList[i], fileMTimeList[i],
@@ -183,8 +193,8 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 					  NULL, fileUIDList[i], 
 					  fileGIDList[i], fileLinktoList[i]);
 			} else {
-			    rpmError(RPMERR_INTERNAL, "package has "
-				    "neither file owner or id lists");
+			    rpmError(RPMERR_INTERNAL, _("package has "
+				    "neither file owner or id lists"));
 			}
 		    }
 		}
@@ -202,10 +212,8 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 static char * permsString(int mode) {
     static char perms[11];
 
-    strcpy(perms, "-----------");
+    strcpy(perms, "----------");
    
-    if (mode & S_ISVTX) perms[10] = 't';
-
     if (mode & S_IRUSR) perms[1] = 'r';
     if (mode & S_IWUSR) perms[2] = 'w';
     if (mode & S_IXUSR) perms[3] = 'x';
@@ -218,6 +226,13 @@ static char * permsString(int mode) {
     if (mode & S_IWOTH) perms[8] = 'w';
     if (mode & S_IXOTH) perms[9] = 'x';
 
+    if (mode & S_ISVTX) {
+	if (mode & S_IXOTH)
+	    perms[9] = 't';
+	else
+	    perms[9] = 'T';
+    }
+
     if (mode & S_ISUID) {
 	if (mode & S_IXUSR) 
 	    perms[3] = 's'; 
@@ -240,7 +255,7 @@ static char * permsString(int mode) {
     else if (S_ISFIFO(mode)) 
 	perms[0] = 'p';
     else if (S_ISSOCK(mode)) 
-	perms[0] = 'l';
+	perms[0] = 's';
     else if (S_ISCHR(mode)) {
 	perms[0] = 'c';
     } else if (S_ISBLK(mode)) {
@@ -312,7 +327,7 @@ static void printFileInfo(char * name, unsigned int size, unsigned short mode,
     else
 	strftime(timefield, sizeof(timefield) - 1, "%b %d  %Y", tstruct);
 
-    printf("%s %8s %8s %10s %s %s\n", perms, ownerfield, groupfield, 
+    fprintf(stdout, "%s %8s %8s %10s %s %s\n", perms, ownerfield, groupfield, 
 		sizefield, timefield, namefield);
 }
 
@@ -323,7 +338,7 @@ static void showMatches(rpmdb db, dbiIndexSet matches, int queryFlags,
 
     for (i = 0; i < matches.count; i++) {
 	if (matches.recs[i].recOffset) {
-	    rpmMessage(RPMMESS_DEBUG, "querying record number %d\n",
+	    rpmMessage(RPMMESS_DEBUG, _("querying record number %d\n"),
 			matches.recs[i].recOffset);
 	    
 	    h = rpmdbGetRecord(db, matches.recs[i].recOffset);
@@ -351,7 +366,7 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
     char *end = NULL;
     struct urlContext context;
     int isUrl = 0;
-    char path[255];
+    char path[PATH_MAX];
 
     if (source != QUERY_RPM) {
 	if (rpmdbOpen(prefix, &db, O_RDONLY, 0644)) {
@@ -464,11 +479,38 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 
       case QUERY_PATH:
 	if (*arg != '/') {
-	    if (realpath(arg, path) != NULL)
+		/* Using realpath on the arg isn't correct if the arg is a symlink,
+		 * especially if the symlink is a dangling link.  What we should
+		 * instead do is use realpath() on `.' and then append arg to
+		 * it.
+		 */
+	    if (realpath(".", path) != NULL) {
+		if (path[strlen(path)] != '/') {
+			if (strncat(path, "/", PATH_MAX - strlen(path) - 1) == NULL) {
+	    		fprintf(stderr, _("maximum path length exceeded\n"));
+	    		return 1;
+			}
+		}
+		/* now append the original file name to the real path */
+		if (strncat(path, arg, PATH_MAX - strlen(path) - 1) == NULL) {
+	    		fprintf(stderr, _("maximum path length exceeded\n"));
+	    		return 1;
+		}
 		arg = path;
+	    }
 	}
 	if (rpmdbFindByFile(db, arg, &matches)) {
-	    fprintf(stderr, _("file %s is not owned by any package\n"), arg);
+	    int myerrno = 0;
+	    if (access(arg, F_OK) != 0)
+		myerrno = errno;
+	    switch (myerrno) {
+	    default:
+		fprintf(stderr, _("file %s: %s\n"), arg, strerror(myerrno));
+		break;
+	    case 0:
+		fprintf(stderr, _("file %s is not owned by any package\n"), arg);
+		break;
+	    }
 	    retcode = 1;
 	} else {
 	    showMatches(db, matches, queryFlags, queryFormat);
@@ -519,8 +561,18 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 void queryPrintTags(void) {
     const struct headerTagTableEntry * t;
     int i;
+    struct headerSprintfExtension * ext = rpmHeaderFormats;
 
     for (i = 0, t = rpmTagTable; i < rpmTagTableSize; i++, t++) {
-	printf("%s\n", t->name + 7);
+	fprintf(stdout, "%s\n", t->name + 7);
+    }
+
+    while (ext->name) {
+	if (ext->type == HEADER_EXT_TAG)
+	    fprintf(stdout, "%s\n", ext->name + 7), ext++;
+	else if (ext->type == HEADER_EXT_MORE)
+	    ext = ext->u.more;
+	else
+	    ext++;
     }
 }
