@@ -46,6 +46,7 @@
 #define GETOPT_RMSOURCE		1015
 #define GETOPT_RELOCATE		1016
 #define GETOPT_TRIGGEREDBY	1017
+#define	GETOPT_SHOWRC		1018
 
 char * version = VERSION;
 
@@ -57,6 +58,7 @@ enum modes { MODE_QUERY, MODE_INSTALL, MODE_UNINSTALL, MODE_VERIFY,
 /* the flags for the various options */
 static int allFiles;
 static int allMatches;
+static char * arch;
 static int badReloc;
 static int clean;
 static int dump;
@@ -77,18 +79,23 @@ static int noFiles;
 static int noMd5;
 static int noPgp;
 static int noScripts;
+static int noTriggers;
+static char * os;
 static int oldPackage;
 static int showPercents;
 static char * pipeOutput;
 static char * prefix;
 static int queryTags;
 static int quiet;
+static char * rcfile;
 static int replaceFiles;
 static int replacePackages;
 static char * rootdir;
 static int shortCircuit;
+static int showrc;
 static int signIt;
 static int test;
+
 static int rpm_version;
 
 /* the structure describing the options we take and the defaults */
@@ -99,8 +106,8 @@ static struct poptOption optionsTable[] = {
 	{ "allmatches", 'a', 0, &allMatches, 0 },
 	{ "badreloc", '\0', 0, &badReloc, 0 },
 	{ "build", 'b', POPT_ARG_STRING, 0, 'b' },
-	{ "buildarch", '\0', POPT_ARG_STRING, 0, 0 },
-	{ "buildos", '\0', POPT_ARG_STRING, 0, 0 },
+	{ "buildarch", '\0', POPT_ARG_STRING, &arch, 0 },
+	{ "buildos", '\0', POPT_ARG_STRING, &os, 0 },
 	{ "buildroot", '\0', POPT_ARG_STRING, 0, GETOPT_BUILDROOT },
 	{ "checksig", 'K', 0, 0, 'K' },
 	{ "clean", '\0', 0, &clean, 0 },
@@ -132,6 +139,7 @@ static struct poptOption optionsTable[] = {
 	{ "nomd5", '\0', 0, &noMd5, 0 },
 	{ "nopgp", '\0', 0, &noPgp, 0 },
 	{ "noscripts", '\0', 0, &noScripts, 0 },
+	{ "notriggers", '\0', 0, &noTriggers, 0 },
 	{ "oldpackage", '\0', 0, &oldPackage, 0 },
 	{ "package", 'p', 0, 0, 'p' },
 	{ "percent", '\0', 0, &showPercents, 0 },
@@ -143,7 +151,7 @@ static struct poptOption optionsTable[] = {
 	{ "queryformat", '\0', POPT_ARG_STRING, 0, GETOPT_QUERYFORMAT },
 	{ "querytags", '\0', 0, &queryTags, 0 },
 	{ "quiet", '\0', 0, &quiet, 0 },
-	{ "rcfile", '\0', POPT_ARG_STRING, 0, 0 },
+	{ "rcfile", '\0', POPT_ARG_STRING, &rcfile, 0 },
 	{ "rebuild", '\0', 0, 0, GETOPT_REBUILD },
 	{ "rebuilddb", '\0', 0, 0, GETOPT_REBUILDDB },
 	{ "recompile", '\0', 0, 0, GETOPT_RECOMPILE },
@@ -154,7 +162,7 @@ static struct poptOption optionsTable[] = {
 	{ "rmsource", '\0', 0, 0, GETOPT_RMSOURCE },
 	{ "root", 'r', POPT_ARG_STRING, &rootdir, 0 },
 	{ "short-circuit", '\0', 0, &shortCircuit, 0 },
-	{ "showrc", '\0', 0, 0, 0 },
+	{ "showrc", '\0', 0, &showrc, GETOPT_SHOWRC },
 	{ "sign", '\0', 0, &signIt, 0 },
 	{ "state", 's', 0, 0, 's' },
 	{ "tarball", 't', POPT_ARG_STRING, 0, 't' },
@@ -177,7 +185,7 @@ static struct poptOption optionsTable[] = {
 static void argerror(char * desc);
 
 static void argerror(char * desc) {
-    fprintf(stderr, "rpm: %s\n", desc);
+    fprintf(stderr, _("rpm: %s\n"), desc);
     exit(1);
 }
 
@@ -188,7 +196,7 @@ static void printUsage(void);
 static void printHelpLine(char * prefix, char * help);
 
 static void printVersion(void) {
-    printf(_("RPM version %s\n"), version);
+    fprintf(stdout, _("RPM version %s\n"), version);
 }
 
 static void printBanner(void) {
@@ -200,7 +208,7 @@ static void printBanner(void) {
 static void printUsage(void) {
     printVersion();
     printBanner();
-    puts("");
+    puts(_(""));
 
     puts(_("usage: rpm {--help}"));
     puts(_("       rpm {--version}"));
@@ -212,7 +220,7 @@ static void printUsage(void) {
     puts(_("                        [--prefix <dir>] [--ignoreos] [--nodeps] [--allfiles]"));
     puts(_("                        [--ftpproxy <host>] [--ftpport <port>] [--justdb]"));
     puts(_("                        [--noorder] [--relocate oldpath=newpath]"));
-    puts(_("                        [--badreloc] file1.rpm ... fileN.rpm"));
+    puts(_("                        [--badreloc] [--notriggers] file1.rpm ... fileN.rpm"));
     puts(_("       rpm {--upgrade -U} [-v] [--hash -h] [--percent] [--force] [--test]"));
     puts(_("                        [--oldpackage] [--root <dir>] [--noscripts]"));
     puts(_("                        [--excludedocs] [--includedocs] [--rcfile <file>]"));
@@ -224,9 +232,9 @@ static void printUsage(void) {
     puts(_("       rpm {--query -q} [-afpg] [-i] [-l] [-s] [-d] [-c] [-v] [-R]"));
     puts(_("                        [--scripts] [--root <dir>] [--rcfile <file>]"));
     puts(_("                        [--whatprovides] [--whatrequires] [--requires]"));
-    puts(_("                        [--ftpuseport] [--ftpproxy <host>] [--ftpport <port>]"));
-    puts(_("                        [--provides] [--dump] [--dbpath <dir>] [--changelog]"));
-    puts(_("                        [targets]"));
+    puts(_("                        [--triggeredby] [--ftpuseport] [--ftpproxy <host>]"));
+    puts(_("                        [--ftpport <port>] [--provides] [--triggers] [--dump]"));
+    puts(_("                        [--changelog] [--dbpath <dir>] [targets]"));
     puts(_("       rpm {--verify -V -y} [-afpg] [--root <dir>] [--rcfile <file>]"));
     puts(_("                        [--dbpath <dir>] [--nodeps] [--nofiles] [--noscripts]"));
     puts(_("                        [--nomd5] [targets]"));
@@ -234,7 +242,7 @@ static void printUsage(void) {
     puts(_("       rpm {--setugids} [-afpg] [target]"));
     puts(_("       rpm {--erase -e} [--root <dir>] [--noscripts] [--rcfile <file>]"));
     puts(_("                        [--dbpath <dir>] [--nodeps] [--allmatches]"));
-    puts(_("                        [--justdb] package1 ... packageN"));
+    puts(_("                        [--justdb] [--notriggers] rpackage1 ... packageN"));
     puts(_("       rpm {-b|t}[plciba] [-v] [--short-circuit] [--clean] [--rcfile  <file>]"));
     puts(_("                        [--sign] [--test] [--timecheck <s>] [--buildos <os>]"));
     puts(_("                        [--buildarch <arch>] [--rmsource] specfile"));
@@ -256,7 +264,7 @@ static void printHelpLine(char * prefix, char * help) {
     char * ch;
     char format[10];
 
-    printf("%s - ", prefix);
+    fprintf(stdout, "%s - ", prefix);
 
     while (helpLength > lineLength) {
 	ch = help + lineLength - 1;
@@ -266,7 +274,7 @@ static void printHelpLine(char * prefix, char * help) {
 	ch++;
 
 	sprintf(format, "%%.%ds\n%%%ds", (int) (ch - help), indentLength);
-	printf(format, help, " ");
+	fprintf(stdout, format, help, " ");
 	help = ch;
 	while (isspace(*help) && *help) help++;
 	helpLength = strlen(help);
@@ -278,223 +286,231 @@ static void printHelpLine(char * prefix, char * help) {
 static void printHelp(void) {
     printVersion();
     printBanner();
-    puts("");
+    puts(_(""));
 
-    puts(_("usage:"));
-    printHelpLine("   --help                 ", 
+    puts(         _("usage:"));
+    printHelpLine(  "   --help                 ", 
 		  _("print this message"));
-    printHelpLine("   --version              ",
+    printHelpLine(  "   --version              ",
 		  _("print the version of rpm being used"));
-    puts(_("   all modes support the following arguments:"));
-    printHelpLine("      --rcfile <file>     ",
+    puts(         _("   all modes support the following arguments:"));
+    printHelpLine(_("      --rcfile <file>     "),
 		  _("use <file> instead of /etc/rpmrc and $HOME/.rpmrc"));
-    printHelpLine("     -v                   ",
+    printHelpLine(  "     -v                   ",
 		  _("be a little more verbose"));
-    printHelpLine("     -vv                  ",
+    printHelpLine(  "     -vv                  ",
 		  _("be incredibly verbose (for debugging)"));
-    printHelpLine("   -q                     ",
+    printHelpLine(  "   -q                     ",
 		  _("query mode"));
-    printHelpLine("      --root <dir>        ",
+    printHelpLine(_("      --root <dir>        "),
 		  _("use <dir> as the top level directory"));
-    printHelpLine("      --dbpath <dir>      ",
+    printHelpLine(_("      --dbpath <dir>      "),
 		  _("use <dir> as the directory for the database"));
-    printHelpLine("      --queryformat <s>   ",
-		  _("use s as the header format (implies -i)"));
-    puts(_("   install, upgrade and query (with -p) allow ftp URL's to be used in place"));
-    puts(_("   of file names as well as the following options:\n"));
-    printHelpLine("      --ftpproxy <host>   ",
+    printHelpLine(_("      --queryformat <qfmt>"),
+		  _("use <qfmt> as the header format (implies -i)"));
+    puts(         _("   install, upgrade and query (with -p) allow ftp URL's to be used in place"));
+    puts(         _("   of file names as well as the following options:"));
+    printHelpLine(_("      --ftpproxy <host>   "),
 		  _("hostname or IP of ftp proxy"));
-    printHelpLine("      --ftpport <port>    ",
+    printHelpLine(_("      --ftpport <port>    "),
 		  _("port number of ftp server (or proxy)"));
-    puts(       _("      Package specification options:"));
-    printHelpLine("        -a                ",
+    puts(         _("      Package specification options:"));
+    printHelpLine(  "        -a                ",
 		  _("query all packages"));
-    printHelpLine("        -f <file>+        ",
+    printHelpLine(_("        -f <file>+        "),
 		  _("query package owning <file>"));
-    printHelpLine("        -p <packagefile>+ ",
+    printHelpLine(_("        -p <packagefile>+ "),
 		  _("query (uninstalled) package <packagefile>"));
-    printHelpLine("        --whatprovides <i>",
-		  _("query packages which provide <i> capability"));
-    printHelpLine("        --whatrequires <i>",
-		  _("query packages which require <i> capability"));
-    puts(_("      Information selection options:"));
-    printHelpLine("        -i                ",
+    printHelpLine(_("        --triggeredby <pkg>"),
+		  _("query packages triggered by <pkg>"));
+    printHelpLine(_("        --whatprovides <cap>"),
+		  _("query packages which provide <cap> capability"));
+    printHelpLine(_("        --whatrequires <cap>"),
+		  _("query packages which require <cap> capability"));
+    puts(         _("      Information selection options:"));
+    printHelpLine(  "        -i                ",
 		  _("display package information"));
-    printHelpLine("        --changelog       ",
+    printHelpLine  ("        --changelog       ",
 		  _("display the package's change log"));
-    printHelpLine("        -l                ",
+    printHelpLine(  "        -l                ",
 		  _("display package file list"));
-    printHelpLine("        -s                ",
+    printHelpLine(  "        -s                ",
 		  _("show file states (implies -l)"));
-    printHelpLine("        -d                ",
+    printHelpLine(  "        -d                ",
 		  _("list only documentation files (implies -l)"));
-    printHelpLine("        -c                ",
+    printHelpLine(  "        -c                ",
 		  _("list only configuration files (implies -l)"));
-    printHelpLine("        --dump            ",
+    printHelpLine(  "        --dump            ",
 		  _("show all verifiable information for each file (must be used with -l, -c, or -d)"));
-    printHelpLine("        --provides        ",
+    printHelpLine(  "        --provides        ",
 		  _("list capabilities package provides"));
-    puts(       _("        --requires"));
-    printHelpLine("        -R                ",
+    puts(         _("        --requires"));
+    printHelpLine(  "        -R                ",
 		  _("list package dependencies"));
-    printHelpLine("        --scripts         ",
+    printHelpLine(  "        --scripts         ",
 		  _("print the various [un]install scripts"));
-    puts(         "");
-    puts(         "    -V");
-    puts(         "    -y");
-    printHelpLine("    --pipe <cmd>        ",
+    printHelpLine(  "        --triggers        ",
+		  _("show the trigger scripts contained in the package"));
+    puts("");
+    puts(           "    -V");
+    puts(           "    -y");
+    printHelpLine(_("    --pipe <cmd>          "),
 		  _("send stdout to <cmd>"));
-    printHelpLine("    --verify              ",
+    printHelpLine(  "    --verify              ",
 		  _("verify a package installation using the same same package specification options as -q"));
-    printHelpLine("      --dbpath <dir>      ",
+    printHelpLine(_("      --dbpath <dir>      "),
 		  _("use <dir> as the directory for the database"));
-    printHelpLine("      --root <dir>        ",
+    printHelpLine(_("      --root <dir>        "),
 		  _("use <dir> as the top level directory"));
-    printHelpLine("      --nodeps            ",
+    printHelpLine(  "      --nodeps            ",
 		  _("do not verify package dependencies"));
-    printHelpLine("      --nomd5             ",
+    printHelpLine(  "      --nomd5             ",
 		  _("do not verify file md5 checksums"));
-    printHelpLine("      --nofiles           ",
+    printHelpLine(  "      --nofiles           ",
 		  _("do not verify file attributes"));
     puts("");
-    printHelpLine("    --setperms            ",
+    printHelpLine(  "    --setperms            ",
 		  _("set the file permissions to those in the package database"
 		    " using the same package specification options as -q"));
-    printHelpLine("    --setugids            ",
+    printHelpLine(  "    --setugids            ",
 		  _("set the file owner and group to those in the package "
 		    "database using the same package specification options as "
 		    "-q"));
     puts("");
-    puts(         "    --install <packagefile>");
-    printHelpLine("    -i <packagefile>      ",
+    puts(         _("    --install <packagefile>"));
+    printHelpLine(_("    -i <packagefile>      "),
 		  _("install package"));
-    printHelpLine("      --relocate <oldpath>=<newpath>",
+    printHelpLine(_("      --relocate <oldpath>=<newpath>"),
 		  _("relocate files from <oldpath> to <newpath>"));
-    printHelpLine("      --badreloc",
+    printHelpLine(  "      --badreloc",
 		  _("relocate files even though the package doesn't allow it"));
-    printHelpLine("      --prefix <dir>      ",
+    printHelpLine(_("      --prefix <dir>      "),
 		  _("relocate the package to <dir>, if relocatable"));
-    printHelpLine("      --dbpath <dir>      ",
+    printHelpLine(_("      --dbpath <dir>      "),
 		  _("use <dir> as the directory for the database"));
-    printHelpLine("      --excludedocs       ",
+    printHelpLine(  "      --excludedocs       ",
 		  _("do not install documentation"));
-    printHelpLine("      --force             ",
+    printHelpLine(  "      --force             ",
 		  _("short hand for --replacepkgs --replacefiles"));
-    puts(         "      -h");
-    printHelpLine("      --hash              ",
+    puts(           "      -h");
+    printHelpLine(  "      --hash              ",
 		  _("print hash marks as package installs (good with -v)"));
-    printHelpLine("      --allfiles          ",
+    printHelpLine(  "      --allfiles          ",
 		  _("install all files, even configurations which might "
 		    "otherwise be skipped"));
-    printHelpLine("      --ignorearch        ",
+    printHelpLine(  "      --ignorearch        ",
 		  _("don't verify package architecture"));
-    printHelpLine("      --ignoreos          ",
+    printHelpLine(  "      --ignoreos          ",
 		  _("don't verify package operating system"));
-    printHelpLine("      --includedocs       ",
+    printHelpLine(  "      --includedocs       ",
 		  _("install documentation"));
-    printHelpLine("      --justdb            ",
+    printHelpLine(  "      --justdb            ",
 		  _("update the database, but do not modify the filesystem"));
-    printHelpLine("      --nodeps            ",
+    printHelpLine(  "      --nodeps            ",
 		  _("do not verify package dependencies"));
-    printHelpLine("      --noorder           ",
+    printHelpLine(  "      --noorder           ",
 		  _("do not reorder package installation to satisfy dependencies"));
-    printHelpLine("      --noscripts         ",
+    printHelpLine(  "      --noscripts         ",
 		  _("don't execute any installation scripts"));
-    printHelpLine("      --percent           ",
+    printHelpLine(  "      --notriggers        ",
+		  _("don't execute any scripts triggered by this package"));
+    printHelpLine(  "      --percent           ",
 		  _("print percentages as package installs"));
-    printHelpLine("      --replacefiles      ",
+    printHelpLine(  "      --replacefiles      ",
 		  _("install even if the package replaces installed files"));
-    printHelpLine("      --replacepkgs       ",
+    printHelpLine(  "      --replacepkgs       ",
 		  _("reinstall if the package is already present"));
-    printHelpLine("      --root <dir>        ",
+    printHelpLine(_("      --root <dir>        "),
 		  _("use <dir> as the top level directory"));
-    printHelpLine("      --test              ",
+    printHelpLine(  "      --test              ",
 		  _("don't install, but tell if it would work or not"));
     puts("");
-    puts(         "    --upgrade <packagefile>");
-    printHelpLine("    -U <packagefile>      ",
+    puts(         _("    --upgrade <packagefile>"));
+    printHelpLine(_("    -U <packagefile>      "),
 		  _("upgrade package (same options as --install, plus)"));
-    printHelpLine("      --oldpackage        ",
+    printHelpLine(  "      --oldpackage        ",
 		  _("upgrade to an old version of the package (--force on upgrades does this automatically)"));
     puts("");
-    puts(         "    --erase <package>");
-    printHelpLine("    -e <package>          ",
+    puts(         _("    --erase <package>"));
+    printHelpLine(  "    -e <package>          ",
 		  _("erase (uninstall) package"));
-    printHelpLine("      --allmatches        ",
+    printHelpLine(  "      --allmatches        ",
 		  _("remove all packages which match <package> (normally an error is generated if <package> specified multiple packages)"));
-    printHelpLine("      --dbpath <dir>      ",
+    printHelpLine(_("      --dbpath <dir>      "),
 		  _("use <dir> as the directory for the database"));
-    printHelpLine("      --justdb            ",
+    printHelpLine(  "      --justdb            ",
 		  _("update the database, but do not modify the filesystem"));
-    printHelpLine("      --nodeps            ",
+    printHelpLine(  "      --nodeps            ",
 		  _("do not verify package dependencies"));
-    printHelpLine("      --noorder           ",
+    printHelpLine(  "      --noorder           ",
 		  _("do not reorder package installation to satisfy dependencies"));
-    printHelpLine("      --noscripts         ",
+    printHelpLine(  "      --noscripts         ",
 		  _("do not execute any package specific scripts"));
-    printHelpLine("      --root <dir>        ",
+    printHelpLine(  "      --notriggers        ",
+		  _("don't execute any scripts triggered by this package"));
+    printHelpLine(_("      --root <dir>        "),
 		  _("use <dir> as the top level directory"));
     puts("");
-    puts(_("    -b<stage> <spec>      "));
-    printHelpLine("    -t<stage> <tarball>      ",
+    puts(         _("    -b<stage> <spec>      "));
+    printHelpLine(_("    -t<stage> <tarball>   "),
 		  _("build package, where <stage> is one of:"));
-    printHelpLine("          p               ",
+    printHelpLine(  "          p               ",
 		  _("prep (unpack sources and apply patches)"));
-    printHelpLine("          l               ",
+    printHelpLine(  "          l               ",
 		  _("list check (do some cursory checks on %files)"));
-    printHelpLine("          c               ",
+    printHelpLine(  "          c               ",
 		  _("compile (prep and compile)"));
-    printHelpLine("          i               ",
+    printHelpLine(  "          i               ",
 		  _("install (prep, compile, install)"));
-    printHelpLine("          b               ",
+    printHelpLine(  "          b               ",
 		  _("binary package (prep, compile, install, package)"));
-    printHelpLine("          a               ",
+    printHelpLine(  "          a               ",
 		  _("bin/src package (prep, compile, install, package)"));
-    printHelpLine("      --short-circuit     ",
+    printHelpLine(  "      --short-circuit     ",
 		  _("skip straight to specified stage (only for c,i)"));
-    printHelpLine("      --clean             ",
+    printHelpLine(  "      --clean             ",
 		  _("remove build tree when done"));
-    printHelpLine("      --rmsource          ",
+    printHelpLine(  "      --rmsource          ",
 		  _("remove sources and spec file when done"));
-    printHelpLine("      --sign              ",
+    printHelpLine(  "      --sign              ",
 		  _("generate PGP signature"));
-    printHelpLine("      --buildroot <dir>     ",
+    printHelpLine(_("      --buildroot <dir>   "),
 		  _("use <dir> as the build root"));
-    printHelpLine("      --buildarch <arch>  ",
+    printHelpLine(_("      --buildarch <arch>  "),
 		  _("build the packages for architecture <arch>"));
-    printHelpLine("      --buildos <os>  ",
+    printHelpLine(_("      --buildos <os>      "),
 		  _("build the packages for ositecture <os>"));
-    printHelpLine("      --test              ",
+    printHelpLine(  "      --test              ",
 		  _("do not execute any stages"));
-    printHelpLine("      --timecheck <s>     ",
-		  _("set the time check to S seconds (0 disables it)"));
+    printHelpLine(  "      --timecheck <secs>  ",
+		  _("set the time check to <secs> seconds (0 disables)"));
     puts("");
-    printHelpLine("    --rebuild <src_pkg>   ",
+    printHelpLine(_("    --rebuild <src_pkg>   "),
 		  _("install source package, build binary package and remove spec file, sources, patches, and icons."));
-    printHelpLine("    --rmsource <spec>   ",
+    printHelpLine(_("    --rmsource <spec>     "),
 		  _("remove sources and spec file"));
-    printHelpLine("    --recompile <src_pkg> ",
+    printHelpLine(_("    --recompile <src_pkg> "),
 		  _("like --rebuild, but don't build any package"));
-    printHelpLine("    --resign <pkg>+       ",
+    printHelpLine(_("    --resign <pkg>+       "),
 		  _("sign a package (discard current signature)"));
-    printHelpLine("    --addsign <pkg>+      ",
+    printHelpLine(_("    --addsign <pkg>+      "),
 		  _("add a signature to a package"));
-    puts(         "    -K");
-    printHelpLine("    --checksig <pkg>+     ",
+    puts(           "    -K");
+    printHelpLine(_("    --checksig <pkg>+     "),
 		  _("verify package signature"));
-    printHelpLine("      --nopgp             ",
+    printHelpLine(  "      --nopgp             ",
 		  _("skip any PGP signatures"));
-    printHelpLine("      --nomd5             ",
+    printHelpLine(  "      --nomd5             ",
 		  _("skip any MD5 signatures"));
-    printHelpLine("    --querytags           ",
+    printHelpLine(  "    --querytags           ",
 		  _("list the tags that can be used in a query format"));
-    printHelpLine("    --initdb              ",
+    printHelpLine(  "    --initdb              ",
 		  _("make sure a valid database exists"));
-    printHelpLine("    --rebuilddb           ",
+    printHelpLine(  "    --rebuilddb           ",
 		  _("rebuild database from existing database"));
-    printHelpLine("      --dbpath <dir>      ",
+    printHelpLine(_("      --dbpath <dir>      "),
 		  _("use <dir> as the directory for the database"));
-    printHelpLine("      --root <dir>        ",
+    printHelpLine(  "      --root <dir>        ",
 		  _("use <dir> as the top level directory"));
 }
 
@@ -506,24 +522,20 @@ int main(int argc, char ** argv) {
     int queryFor = 0;
     int installFlags = 0, uninstallFlags = 0, interfaceFlags = 0;
     int buildAmount = 0;
-    int showrc = 0;
     int gotDbpath = 0, building = 0, verifyFlags;
     int rmsource = 0;
     int checksigFlags = 0;
     int timeCheck = 0;
     int addSign = NEW_SIGNATURE;
-    char * rcfile = NULL, * queryFormat = NULL;
+    char * queryFormat = NULL;
     char buildChar = ' ';
     char * specFile;
     char * tce;
     char * passPhrase = "";
     char * buildRootOverride = NULL, * cookie = NULL;
-    char * arch = NULL;
-    char * os = NULL;
     char * optArg;
     pid_t pipeChild = 0;
     char * pkg;
-    char ** currarg;
     char * errString;
     poptContext optCon;
     char * infoCommand[] = { "--info", NULL };
@@ -537,6 +549,7 @@ int main(int argc, char ** argv) {
     /* set the defaults for the various command line options */
     allFiles = 0;
     allMatches = 0;
+    arch = NULL;
     badReloc = 0;
     clean = 0;
     dump = 0;
@@ -557,7 +570,9 @@ int main(int argc, char ** argv) {
     noMd5 = 0;
     noPgp = 0;
     noScripts = 0;
+    noTriggers = 0;
     oldPackage = 0;
+    os = NULL;
     showPercents = 0;
     pipeOutput = NULL;
     prefix = NULL;
@@ -567,6 +582,7 @@ int main(int argc, char ** argv) {
     replacePackages = 0;
     rootdir = "/";
     shortCircuit = 0;
+    showrc = 0;
     signIt = 0;
     test = 0;
     rpm_version = 0;
@@ -580,28 +596,26 @@ int main(int argc, char ** argv) {
     /* Make a first pass through the arguments, looking for --rcfile */
     /* as well as --arch and --os.  We need to handle that before    */
     /* dealing with the rest of the arguments.                       */
-    currarg = argv;
-    while (*currarg) {
-	if (!strcmp(*currarg, "--rcfile")) {
-	    rcfile = *(++currarg);
-	} else if (!strcmp(*currarg, "--buildarch")) {
-	    arch = *(++currarg);
-	} else if (!strcmp(*currarg, "--buildos")) {
-	    os = *(++currarg);
-	} else if (!strcmp(*currarg, "--showrc")) {
-	    showrc = 1;
-	    building = 1;
-	} else if (!strncmp(*currarg, "-b", 2) ||
-		   !strncmp(*currarg, "-t", 2) ||
-		   !strcmp(*currarg, "--tarbuild") ||
-		   !strcmp(*currarg, "--build") ||
-		   !strcmp(*currarg, "--rebuild") ||
-		   !strcmp(*currarg, "--rmsource") ||
-		   !strcmp(*currarg, "--recompile")) {
-	    building = 1;
-	}
+    optCon = poptGetContext("rpm", argc, argv, optionsTable, 0);
+    poptReadConfigFile(optCon, LIBRPMALIAS_FILENAME);
+    poptReadDefaultConfig(optCon, 1);
+    poptSetExecPath(optCon, RPMCONFIGDIR, 1);
 
-	if (*currarg) currarg++;
+    while ((arg = poptGetNextOpt(optCon)) > 0) {
+	optArg = poptGetOptArg(optCon);
+
+	switch(arg) {
+	  case 'b':
+	  case 't':
+	  case GETOPT_REBUILD:
+	  case GETOPT_RMSOURCE:
+	  case GETOPT_RECOMPILE:
+	  case GETOPT_SHOWRC:	/* showrc set as side effect */
+	    building = 1;
+	    /* fall thru */
+	  default:
+	    break;
+	}
     } 
 
     /* reading this early makes it easy to override */
@@ -612,9 +626,7 @@ int main(int argc, char ** argv) {
 	exit(0);
     }
 
-    optCon = poptGetContext("rpm", argc, argv, optionsTable, 0);
-    poptReadConfigFile(optCon, LIBRPMALIAS_FILENAME);
-    poptReadDefaultConfig(optCon, 1);
+    poptResetContext(optCon);
 
     while ((arg = poptGetNextOpt(optCon)) > 0) {
 	optArg = poptGetOptArg(optCon);
@@ -680,6 +692,7 @@ int main(int argc, char ** argv) {
 	      case 'c':
 	      case 'p':
 	      case 'l':
+	      case 's':
 		break;
 	      default:
 		argerror(errString);
@@ -816,7 +829,8 @@ int main(int argc, char ** argv) {
 
 	  case GETOPT_BUILDROOT:
 	    if (bigMode != MODE_UNKNOWN &&
-		bigMode != MODE_BUILD && bigMode != MODE_REBUILD)
+		bigMode != MODE_BUILD && bigMode != MODE_REBUILD &&
+		bigMode != MODE_TARBUILD)
 		argerror(_("only one major mode may be specified"));
 	    buildRootOverride = optArg;
 	    break;
@@ -883,7 +897,7 @@ int main(int argc, char ** argv) {
 	    break;
 
 	  default:
-	    fprintf(stderr, "Internal error in argument processing :-(\n");
+	    fprintf(stderr, _("Internal error in argument processing :-(\n"));
 	    exit(1);
 	}
     }
@@ -917,7 +931,7 @@ int main(int argc, char ** argv) {
 	    bigMode = MODE_QUERYTAGS;
 
     if (buildRootOverride && bigMode != MODE_BUILD &&
-	bigMode != MODE_REBUILD) {
+	bigMode != MODE_REBUILD && bigMode != MODE_TARBUILD) {
 	argerror("--buildroot may only be used during package builds");
     }
 
@@ -928,7 +942,7 @@ int main(int argc, char ** argv) {
 			"database"));
 
     if (timeCheck && bigMode != MODE_BUILD && bigMode != MODE_REBUILD &&
-	bigMode != MODE_RECOMPILE) 
+	bigMode != MODE_RECOMPILE && bigMode != MODE_TARBUILD) 
 	argerror(_("--timecheck may only be used during package builds"));
     
     if (bigMode != MODE_QUERY && queryFor) 
@@ -1012,6 +1026,10 @@ int main(int argc, char ** argv) {
 	argerror(_("--noscripts may only be specified during package "
 		   "installation, erasure, and verification"));
 
+    if (bigMode != MODE_INSTALL && bigMode != MODE_UNINSTALL && noTriggers)
+	argerror(_("--notriggers may only be specified during package "
+		   "installation, erasure, and verification"));
+
     if (bigMode != MODE_INSTALL && bigMode != MODE_UNINSTALL && 
 	bigMode != MODE_VERIFY && noDeps)
 	argerror(_("--nodeps may only be specified during package "
@@ -1022,7 +1040,7 @@ int main(int argc, char ** argv) {
 		   "verification"));
 
     if (bigMode != MODE_INSTALL && bigMode != MODE_UNINSTALL &&
-	bigMode != MODE_BUILD && test)
+	bigMode != MODE_BUILD && bigMode != MODE_TARBUILD && test )
 	argerror(_("--test may only be specified during package installation, "
 		 "erasure, and building"));
 
@@ -1044,9 +1062,10 @@ int main(int argc, char ** argv) {
     if (bigMode != MODE_BUILD && bigMode != MODE_TARBUILD && shortCircuit) 
 	argerror(_("--short-circuit may only be used during package building"));
 
-    if (shortCircuit && (buildChar != 'c') && (buildChar != 'i')) {
-	argerror(_("--short-circuit may only be used with -bc, -bi, -tc "
-			"or -ti"));
+    if (shortCircuit && (buildChar != 'c') && (buildChar != 'i')
+		     && (buildChar != 's')) {
+	argerror(_("--short-circuit may only be used with -bc, -bi, -bs, -tc "
+			"-ti, or -ts"));
     }
 
     if (oldPackage && !(installFlags & RPMINSTALL_UPGRADE))
@@ -1079,7 +1098,7 @@ int main(int argc, char ** argv) {
 
     if (signIt) {
         if (bigMode == MODE_REBUILD || bigMode == MODE_BUILD ||
-	    bigMode == MODE_RESIGN) {
+	    bigMode == MODE_RESIGN || bigMode == MODE_TARBUILD) {
             if (poptPeekArg(optCon)) {
 		switch (rpmLookupSignatureType()) {
 		  case RPMSIGTAG_PGP:
@@ -1114,7 +1133,7 @@ int main(int argc, char ** argv) {
 	    dup2(p[0], 0);
 	    close(p[0]);
 	    execl("/bin/sh", "/bin/sh", "-c", pipeOutput, NULL);
-	    fprintf(stderr, "exec failed\n");
+	    fprintf(stderr, _("exec failed\n"));
 	}
 
 	close(p[0]);
@@ -1210,6 +1229,9 @@ int main(int argc, char ** argv) {
 	  case 'l':
 	    buildAmount |= RPMBUILD_FILECHECK;
 	    break;
+	  case 's':
+	    buildAmount |= RPMBUILD_PACKAGESOURCE;
+	    break;
 	}
 
 	if (rmsource)
@@ -1237,6 +1259,7 @@ int main(int argc, char ** argv) {
 	    argerror(_("no packages given for uninstall"));
 
 	if (noScripts) uninstallFlags |= RPMUNINSTALL_NOSCRIPTS;
+	if (noTriggers) uninstallFlags |= RPMUNINSTALL_NOTRIGGERS;
 	if (test) uninstallFlags |= RPMUNINSTALL_TEST;
 	if (justdb) uninstallFlags |= RPMUNINSTALL_JUSTDB;
 	if (noDeps) interfaceFlags |= UNINSTALL_NODEPS;
@@ -1254,6 +1277,7 @@ int main(int argc, char ** argv) {
 	if (replacePackages) installFlags |= RPMINSTALL_REPLACEPKG;
 	if (test) installFlags |= RPMINSTALL_TEST;
 	if (noScripts) installFlags |= RPMINSTALL_NOSCRIPTS;
+	if (noTriggers) installFlags |= RPMINSTALL_NOTRIGGERS;
 	if (ignoreArch) installFlags |= RPMINSTALL_NOARCH;
 	if (ignoreOs) installFlags |= RPMINSTALL_NOOS;
 	if (allFiles) installFlags |= RPMINSTALL_ALLFILES;
@@ -1315,11 +1339,11 @@ int main(int argc, char ** argv) {
 	if (!noMd5) verifyFlags |= VERIFY_MD5;
 
 	if (verifySource == VERIFY_EVERY) {
-	    doVerify(rootdir, VERIFY_EVERY, NULL, verifyFlags);
+	    ec = doVerify(rootdir, VERIFY_EVERY, NULL, verifyFlags);
 	} else {
 	    if (!poptPeekArg(optCon))
 		argerror(_("no arguments given for verify"));
-	    doVerify(rootdir, verifySource, poptGetArgs(optCon), verifyFlags);
+	    ec = doVerify(rootdir, verifySource, poptGetArgs(optCon), verifyFlags);
 	}
 	break;
     }
